/*********************************************************************
 *  ポップ音防止
 * 
 * 　PIC12F1822  XC8 Ver1.45
 *         4MHz (内部クロック）
 *
 *      1 VDD         8 VSS
 *      2 RA5         7 RA0 TX
 *   IN 3 RA4         6 RA1
 *      4 MCLR        5 RA2
 * 
 *　AD変換した値をUARTでデータ送信する。
 *  基準電圧に内部 FVRx4 を使用し、0-4vまでは直読とした
 * 　
 * 参考ページ　はじめてのPIC　PIC12F1822　A/D変換
 * http://machoto2.g2.xrea.com/page/P1822/P12_A10.htm
 * *******************************************************************/

#define _XTAL_FREQ 4000000          // delay_ms(x) のための定義

#include <xc.h>
#include <stdio.h>
#include <stdlib.h>

/*****コンフィグレーション設定*********/
// コンフィギュレーション１の設定
#pragma config FOSC = INTOSC    // 内部ｸﾛｯｸを使用する(INTOSC)
#pragma config WDTE = OFF       // ｳｵｯﾁﾄﾞｯｸﾞﾀｲﾏｰ無し(OFF)
#pragma config PWRTE = ON       // 電源ONから64ms後にﾌﾟﾛｸﾞﾗﾑを開始する(ON)
#pragma config MCLRE = OFF      // 外部ﾘｾｯﾄ信号を使用しない
#pragma config CP = OFF         // ﾌﾟﾛｸﾞﾗﾑﾒﾓﾘｰを保護しない(OFF)
#pragma config CPD = OFF        // ﾃﾞｰﾀﾒﾓﾘｰを保護しない(OFF)
#pragma config BOREN = ON       // 電源電圧降下常時監視機能ON(ON)
#pragma config CLKOUTEN = OFF   // CLKOUTﾋﾟﾝをRA6ﾋﾟﾝで使用する(OFF)
#pragma config IESO = OFF       // 外部・内部ｸﾛｯｸの切替えでの起動はなし(OFF)
#pragma config FCMEN = OFF      // 外部ｸﾛｯｸ監視しない(FCMEN_OFF)

// コンフィギュレーション２の設定
#pragma config WRT = OFF        // Flashﾒﾓﾘｰを保護しない(OFF)
#pragma config PLLEN = OFF      // 動作クロックを32MHzでは動作させない(OFF)
#pragma config STVREN = ON      // スタックがオーバフローやアンダーフローしたらリセットをする(ON)
#pragma config BORV = LO        // 電源電圧降下常時監視電圧 設定(LOW)
#pragma config LVP = OFF        // 低電圧プログラミング機能使用しない(OFF)

// ================= printf関数を使用するための定義 =================
void putch(unsigned char ch) {
    while (!TXIF);               // 送信終了待ち
        TXREG = ch;
}

// ******************* main ******************************************
void main() {
    
    unsigned int wait ;
    unsigned int i ;
    unsigned int c ;
    
    OSCCON = 0b01101010;       // 内部クロック4Mhz
    PORTA  = 0x00;
    TRISA  = 0b00010000;       // A/Dのみ入力
    ANSELA = 0x00;             // すべてデジタル
    
//    WPUA   = 0b00000000;       // RA3 弱プルアップ OFF
//  nWPUEN = 1;

//------------ Initialize UART -------------------
    RCSTA   = 0b10000000;      // 非同期送信 9600baud
    TXSTA   = 0b00100100;
    BAUDCON = 0b00001000;
    SPBRGH  = 0;
    SPBRG   = 103;
    // --------- Initialize ADC -----------------
    ANSA4 = 1;                  // AN3はアナログ入力に設定
    ADCON1 = 0b10010011;        // 右詰め出力, AD変換クロックFosc/8
                                // 正基準電圧 FVR
    ADCON0 = 0b00001101;        // アナログ入力 AN3(RA4),ADC ON
    // --------- Initialize FVR -----------------
    FVRCON = 0b10000011;        // ADC用出力 x4(4.096v)に設定

     printf("HELLO\r\n");        //シリアル通信テスト

        GO = 1;                 // AD変換開始
        while(GO);              // AD変換終了待ち
        wait = ADRES*4;         //取得したA/D値をそのままウエイト時間とする。
        
        printf("%4d\r\n",ADRES); // レジスター値を送信
        printf("%4d\r\n",wait);  // AD変換結果送信
        
        for(i=0;i < wait;i++ ){  　//通電してからウエイト時間まで待つ。
       
        __delay_ms(1);
        }
        RA2 = 1;                    //リレーON
    
    // ----------- 繰返し ----------------------------------
    while(1){  }
        
}